@@ -937,18 +937,17 @@ WOK
       widget_sisu_text
     end
     def credits_sisu
-      x=%{<div class="substance">
+      %{<div class="substance">
 <table summary="SiSU summary" bgcolor="#ffffff" cellpadding="4" border="0">
 <tr><td>
   #{widget_sisu}
-  #{widget_way_better}
 </table></div>}
       ''
     end
     def credits_splash
     end
     def credits_sisu_epub
-      x=%{<div class="substance">
+      %{<div class="substance">
 <p class="center"><a href="http://www.openebook.org"><b>EPUB</b></a> generated by <a href="http://www.sisudoc.org"><b>#{@v[:project]}</b></a> v#{@v[:version]}, GPL3</p>
 </div>}
       ''
@@ -1198,7 +1197,7 @@ WOK
       self
     end
     def dimensions
-      d=case @papersize
+      case @papersize
       when /a4/;     a4
       when /letter/; letter
       when /legal/;  legal
