@@ -82,7 +82,7 @@ module SiSU_Embedded
       multimedia
       begin
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
