@@ -124,7 +124,7 @@ module SiSU_HTML
           SiSU_HTML::Source::Output.new(scroll,@md).scroll
         end
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
@@ -269,7 +269,7 @@ module SiSU_HTML
                 @@toc[:seg_mini] << toc[:seg_mini] if toc[:seg_mini]
                 @@toc[:scr] << toc[:scr] if toc[:scr]
               rescue
-                SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+                SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
                   __LINE__.to_s + ':' + __FILE__
                 end
               end
@@ -418,14 +418,21 @@ WOK
         linkname,ocn=dob.obj.strip,dob.ocn
         p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,ocn) if ocn
         if dob.ln ==4
-          seg_link=%{  <a href="#{dob.name}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top">
+          fnh={
+            fn: dob.name,
+          }
+          f=@md.file.base_filename.html_seg(fnh)
+          seg_link=%{  <a href="#{f}" target="_top">
     #{dob.obj}
   </a> }
           @@seg_url=dob.name
         elsif dob.obj =~/\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+/
-          seg_link=dob.obj.gsub(/^(\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+)(.*)/,
-            %{<a href="\\1#{@md.lang_code_insert}#{Sfx[:html]}" } +
-            %{target="_top">\\1 \\2</a> })
+          fn,hd=/^(\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+)(.*)/.match(dob.obj)[1,2]
+          fnh={
+            fn: fn,
+          }
+          f=@md.file.base_filename.html_seg(fnh)
+          seg_link=%{<a href="#{f}" target="_top">#{fn} #{hd}</a> }
         end
         p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,ocn) if ocn
         @file=SiSU_Env::FileOp.new(@md) if @md
@@ -459,8 +466,12 @@ WOK
         toc={}
         if ocn \
         and ocn !~/#/
+          fnh={
+            fn: @@seg_url,
+          }
+          f=@md.file.base_filename.html_seg(fnh)
           p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,ocn)
-          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:html]}##{ocn}">
+          lnk_n_txt=%{  <a href="#{f}##{ocn}">
     #{linkname}
   </a>}
           txt_obj={ txt: lnk_n_txt }
@@ -480,8 +491,12 @@ WOK
         toc={}
         if ocn \
         and ocn !~/#/
+          fnh={
+            fn: @@seg_url,
+          }
+          f=@md.file.base_filename.html_seg(fnh)
           p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,ocn)
-          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:html]}##{ocn}">
+          lnk_n_txt=%{  <a href="#{f}##{ocn}">
   #{linkname}
 </a>}
           txt_obj={ txt: lnk_n_txt }
@@ -646,7 +661,7 @@ WOK
               end
             end
           rescue
-            SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
               __LINE__.to_s + ':' + __FILE__
             end
           ensure
@@ -668,7 +683,7 @@ WOK
               end
             end
           rescue
-            SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+            SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
               __LINE__.to_s + ':' + __FILE__
             end
           ensure
