@@ -75,9 +75,9 @@ module SiSU
   class HubMaster
     def initialize(argv)
       pwd_the=Dir.pwd
-      begin                                                              #% select what to do
-        opt=SiSU_Commandline::Options.new(argv)
-        SiSU::Processing.new(opt).actions
+      begin                                            #% select what to do (set options & start processing (files selected if any))
+        opt=SiSU_Commandline::Options.new(argv)        #  command line selection of what to do, files & operations set
+        SiSU::Processing.new(opt).actions              #  do it
       rescue
         cmd=(opt ? opt.cmd : '')
         SiSU_Screen::Ansi.new(cmd,$!,$@).rescue do
