@@ -96,7 +96,7 @@ module SiSU_Manpage
         @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
         SiSU_Manpage::Source::Scroll.new(@md,@dal_array).songsheet
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
