@@ -1072,6 +1072,6 @@ module SiSU_Commandline
   end
 end
 __END__
-note usually named @opt is carried in Param usually as @md @opt is a subset of
-@md where @md is passed, contents of @opt are available as @md.opt passing @opt
-as well is duplication check for fns & fnb
+note usually named @opt is carried in Param (usually as @md.opt), @opt is a
+subset of @md where @md is passed, contents of @opt are available as @md.opt
+passing @opt as well is duplication check for fns & fnb
