@@ -278,7 +278,7 @@ module SiSU_Translate
       @lang_class.language_list
     end
     def language_list
-      lang=case @trans_str
+      case @trans_str
       when /American/i;                  'American English'                    # tag depreciated, see iso 639-2
       when /English/i;                   'English'
       when /French/i;                    'français'
@@ -497,7 +497,7 @@ module SiSU_Translate
       'Document Metadata'
     end
     def language_list_translated
-      lang=case @trans_str
+      case @trans_str
       when /American/i;                  'American English'                    # tag depreciated, see iso 639-2
       when /English/i;                   'English'
       when /French/i;                    'French'
@@ -712,7 +712,7 @@ module SiSU_Translate
       'Manifeste SiSU des métadonnées du document'
     end
     def language_list_translated
-      lang=case @trans_str
+      case @trans_str
       when /American/i;                  'Anglais americain'                   # tag depreciated, see iso 639-2
       when /English/i;                   'Anglais'
       when /French/i;                    'Français'
@@ -924,7 +924,7 @@ module SiSU_Translate
       'SiSU Zusammenfassung der Metadaten'
     end
     def language_list_translated
-      lang=case @trans_str
+      case @trans_str
       when /American/i;                  'Amerikanisch-Englisch'               # tag depreciated, see iso 639-2
       when /English/i;                   'Englisch'
       when /French/i;                    'Französisch'
@@ -1136,7 +1136,7 @@ module SiSU_Translate
       'Manifiesto SiSU de metadatos de documento'
     end
     def language_list_translated
-      lang=case @trans_str
+      case @trans_str
       when /American/i;                  'Inglés Americano'                     # tag depreciated, see iso 639-2
       when /English/i;                   'Inglés'
       when /French/i;                    'Francés'
@@ -1348,7 +1348,7 @@ module SiSU_Translate
       'Inventario SiSU dei metadati'
     end
     def language_list_translated
-      lang=case @trans_str
+      case @trans_str
       when /American/i;                  'Inglese USA'                         # tag depreciated, see iso 639-2
       when /English/i;                   'Inglese'
       when /French/i;                    'Francese'
@@ -1560,7 +1560,7 @@ module SiSU_Translate
       'Dokumenttimetadatan SISU-manifesti'
     end
     def language_list_translated
-      lang=case @trans_str
+      case @trans_str
       when /American/i;                  'Amerikanenglanti'                    # tag depreciated, see iso 639-2
       when /English/i;                   'Englanti'
       when /French/i;                    'Ranska'
