@@ -1878,7 +1878,7 @@ output_epub_cont_seg.close
         @ocn=((defined? t_o.ocn) ? t_o.ocn.to_s : nil)
         @headname=((t_o.is==:heading and defined? t_o.name) ? t_o.name : nil)
       else
-        if @md.opt.cmd =~/M/
+        if @md.opt.act[:maintenance][:set]==:on
           p __FILE__ << ':' << __LINE__.to_s
           p t_o.class
           p caller
