@@ -173,7 +173,11 @@ WOK
       @@seg_name_xhtml=@@seg_name
       @@seg_total=@@seg_name.length
       testforartnum=@@seg_name_xhtml
-      SiSU_Screen::Ansi.new(@md.opt.cmd,@@seg_name.length) if @md.opt.cmd =~/[MVv]/
+      if (@md.opt.act[:verbose][:set]==:on \
+      || @md.opt.act[:verbose_plus][:set]==:on \
+      || @md.opt.act[:maintenance][:set]==:on)
+        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],@@seg_name.length)
+      end
       SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
       data.each do |dob|
         #if defined? dob.obj \
