@@ -150,7 +150,10 @@ module SiSU_HarvestTopics
         else { filename: filename, file: file, rough_idx: @idx_list, title: @fulltitle, author: creator, page: page, lang: lang  }
         end
       else
-        p "missing required field in #{@filename} - [title]: <<#{@title}>>; [author]: <<#{@author_format}>>; [idx]: <<#{@idx_list}>>" if @opt.cmd.inspect =~/[VM]/
+        if (@opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on)
+          p "missing required field in #{@filename} - [title]: <<#{@title}>>; [author]: <<#{@author_format}>>; [idx]: <<#{@idx_list}>>"
+        end
       end
       idx_array[lang]=idx_array[lang].flatten
       idx_array
@@ -472,10 +475,14 @@ module SiSU_HarvestTopics
           file="#{harvest_pth}/topics.#{lng}.html"
         end
         FileUtils::mkdir_p(harvest_pth) unless FileTest.directory?(harvest_pth)
-        fileinfo=(@opt.cmd =~/[vVM]/) ? ("file://#{file}") : ''
-        SiSU_Screen::Ansi.new(@opt.cmd,"harvest topics(#{@opt.files.length} files)",fileinfo).dark_grey_title_hi unless @opt.cmd =~/q/
+        fileinfo=(@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on) \
+        ? ("file://#{file}")
+        : ''
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"harvest topics(#{@opt.files.length} files)",fileinfo).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
         @output[lng][:html]=File.new(file,'w')
-        if @opt.cmd.inspect =~/[M]/
+        if @opt.act[:maintenance][:set]==:on
           @output[lng][:html_mnt]=File.new("#{@env.path.pwd}/topics.html",'w')
         end
       end
@@ -651,7 +658,7 @@ WOK
       end
       def html_head
         @the_idx.keys.each do |lng|
-          @output[lng][:html_mnt] << html_head_adjust(lng,'maintenance') if @opt.cmd.inspect =~/M/
+          @output[lng][:html_mnt] << html_head_adjust(lng,'maintenance') if @opt.act[:maintenance][:set]==:on
           @output[lng][:html] << html_head_adjust(lng)
         end
       end
@@ -665,7 +672,7 @@ WOK
         end
         a=a.join
         @the_idx.keys.each do |lng|
-          @output[lng][:html_mnt] << a if @opt.cmd.inspect =~/M/
+          @output[lng][:html_mnt] << a if @opt.act[:maintenance][:set]==:on
           @output[lng][:html] << a
         end
       end
