@@ -206,7 +206,11 @@ module SiSU_HTML_Seg
       @@seg_name_html=@@seg_name
       @@seg_total=@@seg_name.length
       testforartnum=@@seg_name_html
-      SiSU_Screen::Ansi.new(@md.opt.cmd,@@seg_name.length).segmented if @md.opt.cmd =~/[MVv]/
+      if (@md.opt.act[:verbose][:set]==:on \
+      || @md.opt.act[:verbose_plus][:set]==:on \
+      || @md.opt.act[:maintenance][:set]==:on)
+        SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],@@seg_name.length).segmented
+      end
       map_nametags=SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
       data.each do |dob|
         if defined? dob.obj \
