@@ -91,6 +91,8 @@ module SiSU_i18n
           ia:    { c: 'ia',    n: 'Interlingua',       t: 'Interlingua',                 xlp: 'interlingua'      },
           is:    { c: 'is',    n: 'Icelandic',         t: 'Icelandic',                   xlp: 'icelandic'        },
           it:    { c: 'it',    n: 'Italian',           t: 'Italiano',                    xlp: 'italian'          },
+          ja:    { c: 'ja',    n: 'Japanese',          t: '日本語 (Nihongo)',            xlp: 'japanese'         },
+          ko:    { c: 'ko',    n: 'Korean',            t: 'Korean',                      xlp: 'korean'           },
           la:    { c: 'la',    n: 'Latin',             t: 'Latin',                       xlp: 'latin'            },
           lo:    { c: 'lo',    n: 'Lao',               t: 'Lao',                         xlp: 'lao'              },
           lt:    { c: 'lt',    n: 'Lithuanian',        t: 'Lithuanian',                  xlp: 'lithuanian'       },
@@ -122,6 +124,7 @@ module SiSU_i18n
           ur:    { c: 'ur',    n: 'Urdu',              t: 'Urdu',                        xlp: 'urdu'             },
           us:    { c: 'en',    n: 'English (American)',t: 'English',                     xlp: 'english'          },
           vi:    { c: 'vi',    n: 'Vietnamese',        t: 'Vietnamese',                  xlp: 'vietnamese'       },
+          zh:    { c: 'zh',    n: 'Chinese',           t: '中文',                        xlp: 'chinese'          },
           en:    { c: 'en',    n: 'English',           t: 'English',                     xlp: 'english'          },
           xx:    { c: 'xx',    n: 'Default',           t: 'English',                     xlp: 'english'          },
         }
@@ -154,6 +157,8 @@ module SiSU_i18n
           'ia'    => table[:ia],
           'is'    => table[:is],
           'it'    => table[:it],
+          'ja'    => table[:ja],
+          'ko'    => table[:ko],
           'la'    => table[:la],
           'lo'    => table[:lo],
           'lt'    => table[:lt],
@@ -185,6 +190,7 @@ module SiSU_i18n
           'ur'    => table[:ur],
           'us'    => table[:en],
           'vi'    => table[:vi],
+          'zh'    => table[:zh],
           'en'    => table[:en],
           'xx'    => table[:en]
         }
@@ -231,7 +237,7 @@ __END__
 Language Lists
 * po4a c:
   <http://www.debian.org/international/l10n/po/>
-  Px[:lng_lst]=%w[am bg bn br ca cs cy da de el en eo es et eu fi fr ga gl he hi hr hy ia is it la lo lt lv ml mr nl nn no oc pl pt pt_BR ro ru sa se sk sl sq sr sv ta te th tk tr uk ur us vi]
+  Px[:lng_lst] see constants.rb
 * polyglossia xlp:
   <http://mirrors.ctan.org/macros/xetex/latex/polyglossia/polyglossia.pdf>
   missing from (:c) list:
