@@ -418,12 +418,7 @@ module SiSU_Manifest
           summarize(id,file,pth,rel,url)
         end
         if FileTest.file?(@f.place_file.txt.dir)==true
-        id=if @md.opt.cmd =~/a/ then 'Plaintext (Unix (UTF-8) with footnotes)'
-        elsif @md.opt.cmd =~/e/ then 'Plaintext (Unix (UTF-8) with endnotes)'
-        elsif @md.opt.cmd =~/A/ then 'Plaintext (dos (UTF-8) with footnotes)'
-        elsif @md.opt.cmd =~/E/ then 'Plaintext (dos (UTF-8) with endnotes)'
-        else                         'Plaintext (UTF-8)'
-        end
+          id='Plaintext (UTF-8)'
           pth=@f.output_path.txt.dir
           rel=@f.output_path.txt.rel_sm
           url=@f.output_path.txt.url
