@@ -71,8 +71,8 @@ module SiSU_KdiSource
       @output_path="#{@env.path.output}/#{@opt.fnb}"
     end
     def read
-      SiSU_Screen::Ansi.new(@opt.cmd,'Share Kdissert Source Document!',@opt.fnb).green_hi_blue unless @opt.cmd =~/q/
-      SiSU_Screen::Ansi.new(@opt.cmd,"Copy kdissert file to output directory","#{@opt.fnb} -> #{@output_path}").warn unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Share Kdissert Source Document!',@opt.fnb).green_hi_blue unless @opt.act[:quiet][:set]==:on
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"Copy kdissert file to output directory","#{@opt.fnb} -> #{@output_path}").warn unless @opt.act[:quiet][:set]==:on
       FileUtils::mkdir_p(@env.path.output) unless FileTest.directory?(@env.path.output)
       FileUtils::mkdir_p(@output_path) unless FileTest.directory?(@output_path)
       if FileTest.directory?(@output_path)
@@ -81,7 +81,7 @@ module SiSU_KdiSource
           FileUtils::cp(@opt.fnb,@output_path)
         end
       else
-        SiSU_Screen::Ansi.new(@opt.cmd,"Output directory does not exist","#{@opt.fnb} -> #{@output_path}").warn unless @opt.cmd =~/q/
+        SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],"Output directory does not exist","#{@opt.fnb} -> #{@output_path}").warn unless @opt.act[:quiet][:set]==:on
         exit
       end
     end
