@@ -82,7 +82,6 @@ module SiSU_TexInfoFormat
     def head
       t=Time.now
       year=t.year
-      filename=%{#{@md.fns}}[/(.+?)\.\w\w\d\d$/,1]
       title=spec_char(@md.title.full)
       title=title.gsub(/<(br|p|i)>|<\/\s*(br|p|i)>|<(br|p)\s*\/>/," #{Tex[:backslash]*2} ").
         gsub(/\$/,"\\$").
@@ -98,7 +97,7 @@ module SiSU_TexInfoFormat
       author=@md.author if @md.author
       author ||=''
       author=author.gsub(/[\*]/,'') #if author
-      v=SiSU_Env::InfoVersion.instance.get_version
+      SiSU_Env::InfoVersion.instance.get_version
       head =<<WOK
 \\input texinfo   @c -*-texinfo-*-
 @comment %**start of header
@@ -165,8 +164,6 @@ WOK
         "@menu\n"
     end
     def dublincore
-      title=spec_char(@md.title.main) if @md.title.main
-      subtitle=spec_char(@md.title.sub) if @md.title.sub
       if defined? @md.title.full \
       and @md.title.full=~/\S+/
         full_title=spec_char(@md.title.full)
@@ -465,7 +462,7 @@ WOK
       @row_break='\\\\\\\\'
       @break_page="#{@row_break}\n#{@row_break} \n"
       if @dob[/#{Mx[:gr_o]}Th?#{Mx[:tc_p]}\s+c(\d+);(.+?)#{Mx[:gr_c]}/ui] #fix
-        no_of_cols,cols_width=$1,$2
+        cols_width=$2
         @w=cols_width.split(/;\s+/)
         @colW=[]
         @w.each  do |x|
@@ -489,7 +486,6 @@ WOK
         else
           @dob.obj=@dob.obj.gsub(/#{Mx[:tc_o]}#{Mx[:tc_p]}/u,'')
           @@table_pg_break_counter+=1
-          tablefoot=@dob[/\<!f(.+?)!\>/]
           @dob.obj=@dob.obj.gsub(/\<!f(.+?)!\>/,'')
         end
       end
@@ -517,7 +513,7 @@ WOK
     def png
       # very messy clean up ! - work area, testing
       z=@dob[/\\\{(.+?)\}(?:image|png)/,1] # match operator for z \\ fragile !
-      image,w,x,y=z.scan(/\S+/)
+      image=z.scan(/\S+/)[0] #image,w,x,y=z.scan(/\S+/)
       image=image.gsub(/\\/,'')
       @dob.obj=@dob.obj.gsub(/\\\{\S+\.(png|jpg|gif).+?\}(image|png)/,"<image #{image} not available>")  # fragile match operator\\ fragile !
     end
@@ -526,7 +522,7 @@ WOK
       z=@dob[/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,1] # match operator for z \\ fragile !
       url=@dob[/((?:https?|file|ftp):\S+)/im,1]
       if @dob =~/\.(png|jpg|gif)/
-        image,w,x,y=z.scan(/\S+/)
+        image=z.scan(/\S+/)[0] #image,w,x,y=z.scan(/\S+/)
         image=image.gsub(/\\/,'')
         width=200
         width=z[/w=(\d+)/im,1] if z =~/w=(\d+)/
