@@ -83,17 +83,23 @@ module SiSU_XHTML
     def read
       begin
         @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
-        unless @opt.cmd =~/q/
-          tool=if @opt.cmd =~/[MV]/
+        unless @opt.act[:quiet][:set]==:on
+          tool=if (@opt.act[:verbose_plus][:set]==:on \
+          || @opt.act[:maintenance][:set]==:on)
             "#{@env.program.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
-          elsif @opt.cmd =~/v/
+          elsif @opt.act[:verbose][:set]==:on
             "#{@env.program.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
           else "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
           end
-          @opt.cmd=~/[MVvz]/ \
-          ? SiSU_Screen::Ansi.new(@opt.cmd,'XHTML',tool).green_hi_blue
-          : SiSU_Screen::Ansi.new(@opt.cmd,'XHTML',tool).green_title_hi
-          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"/#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}").flow if @opt.cmd =~/[MV]/
+          (@opt.act[:verbose][:set]==:on \
+          || @opt.act[:verbose_plus][:set]==:on \
+          || @opt.act[:maintenance][:set]==:on) \
+          ? SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XHTML',tool).green_hi_blue
+          : SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'XHTML',tool).green_title_hi
+          if (@opt.act[:verbose_plus][:set]==:on \
+          || @opt.act[:maintenance][:set]==:on)
+            SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@opt.fns,"/#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}").flow
+          end
         end
         SiSU_XHTML::Source::Songsheet.new(@particulars).song
       rescue
@@ -113,8 +119,12 @@ module SiSU_XHTML
       def song
         begin
           SiSU_XHTML::Source::Scroll.new(@particulars).songsheet
-          SiSU_XHTML::Source::Tidy.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.cmd =~/[vVM]/ # test wellformedness, comment out when not in use
-          SiSU_Rexml::Rexml.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.cmd =~/M/ # test rexml parsing, comment out when not in use #debug
+          if (@md.opt.act[:verbose][:set]==:on \
+          || @md.opt.act[:verbose_plus][:set]==:on \
+          || @md.opt.act[:maintenance][:set]==:on)
+            SiSU_XHTML::Source::Tidy.new(@md,@file.place_file.xhtml.dir).xml # test wellformedness, comment out when not in use
+          end
+          SiSU_Rexml::Rexml.new(@md,@file.place_file.xhtml.dir).xml if @md.opt.act[:maintenance][:set]==:on # test rexml parsing, comment out when not in use #debug
         rescue
           SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
             __LINE__.to_s + ':' + __FILE__
@@ -413,16 +423,17 @@ WOK
       end
       def xml
         if @prog.tidy !=false
-          if @md.opt.cmd =~/[VM]/
-            unless @md.opt.cmd =~/q/
-              SiSU_Screen::Ansi.new(@md.opt.cmd,'invert','Using XML Tidy','check document structure').colorize
-              tell=SiSU_Screen::Ansi.new(@md.opt.cmd,'invert','','')
+          if (@md.opt.act[:verbose_plus][:set]==:on \
+          || @md.opt.act[:maintenance][:set]==:on)
+            unless @md.opt.act[:quiet][:set]==:on
+              SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','Using XML Tidy','check document structure').colorize
+              tell=SiSU_Screen::Ansi.new(@md.opt.act[:color_state][:set],'invert','','')
               tell.grey_open
             end
             tidyfile='/dev/null' #don't want one or screen output, check for alternative flags
             tidy=SiSU_Env::SystemCall.new(@file,tidyfile)
             tidy.well_formed?
-            tell.p_off unless @md.opt.cmd =~/q/
+            tell.p_off unless @md.opt.act[:quiet][:set]==:on
           end
         end
       end
